Documentation
¶
Index ¶
Constants ¶
const DecryptionProviderSOPS = "sops"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KustomizationReconciler ¶
type KustomizationReconciler struct {
client.Client
Log logr.Logger
Scheme *runtime.Scheme
EventRecorder kuberecorder.EventRecorder
ExternalEventRecorder *events.Recorder
MetricsRecorder *metrics.Recorder
StatusPoller *polling.StatusPoller
// contains filtered or unexported fields
}
KustomizationReconciler reconciles a Kustomization object
func (*KustomizationReconciler) SetupWithManager ¶
func (r *KustomizationReconciler) SetupWithManager(mgr ctrl.Manager, opts KustomizationReconcilerOptions) error
type KustomizeDecryptor ¶ added in v0.0.9
func NewDecryptor ¶ added in v0.0.9
func NewDecryptor(kubeClient client.Client, kustomization kustomizev1.Kustomization, homeDir string) *KustomizeDecryptor
func NewTempDecryptor ¶ added in v0.0.9
func NewTempDecryptor(kubeClient client.Client, kustomization kustomizev1.Kustomization) (*KustomizeDecryptor, func(), error)
func (*KustomizeDecryptor) ImportKeys ¶ added in v0.0.9
func (kd *KustomizeDecryptor) ImportKeys(ctx context.Context) error
type KustomizeGarbageCollector ¶ added in v0.0.9
func NewGarbageCollector ¶ added in v0.0.9
func NewGarbageCollector(kubeClient client.Client, snapshot kustomizev1.Snapshot, newChecksum string, log logr.Logger) *KustomizeGarbageCollector
func (*KustomizeGarbageCollector) Prune ¶ added in v0.0.9
func (kgc *KustomizeGarbageCollector) Prune(timeout time.Duration, name string, namespace string) (string, bool)
Prune deletes Kubernetes objects removed from source. Namespaced objects are removed before global ones, as in CRs before CRDs. The garbage collector determines what objects to prune based on a label selector that contains the previously applied revision. The garbage collector ignores objects that are no longer present on the cluster or if they are marked for deleting using Kubernetes finalizers.
type KustomizeGenerator ¶ added in v0.0.9
type KustomizeGenerator struct {
// contains filtered or unexported fields
}
func NewGenerator ¶ added in v0.0.9
func NewGenerator(kustomization kustomizev1.Kustomization) *KustomizeGenerator
type KustomizeHealthCheck ¶ added in v0.0.12
type KustomizeHealthCheck struct {
// contains filtered or unexported fields
}
func NewHealthCheck ¶ added in v0.0.12
func NewHealthCheck(kustomization kustomizev1.Kustomization, statusPoller *polling.StatusPoller) *KustomizeHealthCheck
type SourceRevisionChangePredicate ¶ added in v0.2.0
func (SourceRevisionChangePredicate) Create ¶ added in v0.2.0
func (SourceRevisionChangePredicate) Create(e event.CreateEvent) bool
func (SourceRevisionChangePredicate) Delete ¶ added in v0.2.0
func (SourceRevisionChangePredicate) Delete(e event.DeleteEvent) bool
func (SourceRevisionChangePredicate) Update ¶ added in v0.2.0
func (SourceRevisionChangePredicate) Update(e event.UpdateEvent) bool
Click to show internal directories.
Click to hide internal directories.